@@ -4,20 +4,11 @@ import sqlalchemy as sa
 import sqlmodel as sqm
 from lamin_logger import logger
 
+from ._assets._schemas import get_schema_module_name
 from ._db import insert
 from ._settings_instance import InstanceSettings
 from ._settings_user import UserSettings
 
-known_schema_names = [
-    "bionty",
-    "wetlab",
-    "drylab",
-    "bfx",
-    "retro",
-    "swarm",
-    "harmonic-docking",
-]
-
 
 def create_schema_if_not_exists(schema_name: str, isettings: InstanceSettings):
     # create the schema module in case it doesn't exist
@@ -28,13 +19,6 @@ def create_schema_if_not_exists(schema_name: str, isettings: InstanceSettings):
             conn.commit()
 
 
-def get_schema_module_name(schema_name):
-    if schema_name == "bfx":
-        return "lnbfx.schema"
-    else:
-        return f"lnschema_{schema_name.replace('-', '_')}"
-
-
 def reload_orms(schema_name, module, isettings):
     orms = [cls for cls in module.__dict__.values() if hasattr(cls, "__table__")]
     if isettings._dbconfig == "sqlite":
